==> zio-aws-docdb_2.13-5.17.102.9-sources.jar: zio/aws/docdb/model/package.scala <==
package zio.aws.docdb
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.docdb.model.primitives.Integer.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object BooleanOptional extends Subtype[Boolean]
    type BooleanOptional = zio.aws.docdb.model.primitives.BooleanOptional.Type
    object GlobalClusterIdentifier extends Subtype[String]
    type GlobalClusterIdentifier =
      zio.aws.docdb.model.primitives.GlobalClusterIdentifier.Type
    object Integer extends Subtype[Int]
    type Integer = zio.aws.docdb.model.primitives.Integer.Type
    object IntegerOptional extends Subtype[Int]
    type IntegerOptional = zio.aws.docdb.model.primitives.IntegerOptional.Type
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.docdb.model.primitives.TStamp.Type
  }
  type AttributeValueList = List[String]
  type AvailabilityZoneList = List[zio.aws.docdb.model.AvailabilityZone]
  type AvailabilityZones = List[String]
  type CertificateList = List[zio.aws.docdb.model.Certificate]
  type DBClusterList = List[zio.aws.docdb.model.DBCluster]
  type DBClusterMemberList = List[zio.aws.docdb.model.DBClusterMember]
  type DBClusterParameterGroupList =
    List[zio.aws.docdb.model.DBClusterParameterGroup]
  type DBClusterRoles = List[zio.aws.docdb.model.DBClusterRole]
  type DBClusterSnapshotAttributeList =
    List[zio.aws.docdb.model.DBClusterSnapshotAttribute]
  type DBClusterSnapshotList = List[zio.aws.docdb.model.DBClusterSnapshot]
  type DBEngineVersionList = List[zio.aws.docdb.model.DBEngineVersion]
  type DBInstanceList = List[zio.aws.docdb.model.DBInstance]
  type DBInstanceStatusInfoList = List[zio.aws.docdb.model.DBInstanceStatusInfo]
  type DBSubnetGroups = List[zio.aws.docdb.model.DBSubnetGroup]
  type EventCategoriesList = List[String]
  type EventCategoriesMapList = List[zio.aws.docdb.model.EventCategoriesMap]
  type EventList = List[zio.aws.docdb.model.Event]
  type EventSubscriptionsList = List[zio.aws.docdb.model.EventSubscription]
  type FilterList = List[zio.aws.docdb.model.Filter]
  type FilterValueList = List[String]
  type GlobalClusterList = List[zio.aws.docdb.model.GlobalCluster]
  type GlobalClusterMemberList = List[zio.aws.docdb.model.GlobalClusterMember]
  type KeyList = List[String]
  type LogTypeList = List[String]
  type OrderableDBInstanceOptionsList =
    List[zio.aws.docdb.model.OrderableDBInstanceOption]
  type ParametersList = List[zio.aws.docdb.model.Parameter]
  type PendingMaintenanceActionDetails =
    List[zio.aws.docdb.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.docdb.model.ResourcePendingMaintenanceActions]
  type ReadReplicaIdentifierList = List[String]
  type ReadersArnList = List[String]
  type SourceIdsList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.docdb.model.Subnet]
  type TagList = List[zio.aws.docdb.model.Tag]
  type ValidUpgradeTargetList = List[zio.aws.docdb.model.UpgradeTarget]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.docdb.model.VpcSecurityGroupMembership]
}

==> zio-aws-docdb_2.13-5.17.146.1-sources.jar: zio/aws/docdb/model/package.scala <==
package zio.aws.docdb
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.docdb.model.primitives.GlobalClusterIdentifier.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    type BooleanOptional = Boolean
    object GlobalClusterIdentifier extends Subtype[String]
    type GlobalClusterIdentifier =
      zio.aws.docdb.model.primitives.GlobalClusterIdentifier.Type
    type Integer = Int
    type IntegerOptional = Int
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.docdb.model.primitives.TStamp.Type
  }
  type AttributeValueList = List[String]
  type AvailabilityZoneList = List[zio.aws.docdb.model.AvailabilityZone]
  type AvailabilityZones = List[String]
  type CertificateList = List[zio.aws.docdb.model.Certificate]
  type DBClusterList = List[zio.aws.docdb.model.DBCluster]
  type DBClusterMemberList = List[zio.aws.docdb.model.DBClusterMember]
  type DBClusterParameterGroupList =
    List[zio.aws.docdb.model.DBClusterParameterGroup]
  type DBClusterRoles = List[zio.aws.docdb.model.DBClusterRole]
  type DBClusterSnapshotAttributeList =
    List[zio.aws.docdb.model.DBClusterSnapshotAttribute]
  type DBClusterSnapshotList = List[zio.aws.docdb.model.DBClusterSnapshot]
  type DBEngineVersionList = List[zio.aws.docdb.model.DBEngineVersion]
  type DBInstanceList = List[zio.aws.docdb.model.DBInstance]
  type DBInstanceStatusInfoList = List[zio.aws.docdb.model.DBInstanceStatusInfo]
  type DBSubnetGroups = List[zio.aws.docdb.model.DBSubnetGroup]
  type EventCategoriesList = List[String]
  type EventCategoriesMapList = List[zio.aws.docdb.model.EventCategoriesMap]
  type EventList = List[zio.aws.docdb.model.Event]
  type EventSubscriptionsList = List[zio.aws.docdb.model.EventSubscription]
  type FilterList = List[zio.aws.docdb.model.Filter]
  type FilterValueList = List[String]
  type GlobalClusterList = List[zio.aws.docdb.model.GlobalCluster]
  type GlobalClusterMemberList = List[zio.aws.docdb.model.GlobalClusterMember]
  type KeyList = List[String]
  type LogTypeList = List[String]
  type OrderableDBInstanceOptionsList =
    List[zio.aws.docdb.model.OrderableDBInstanceOption]
  type ParametersList = List[zio.aws.docdb.model.Parameter]
  type PendingMaintenanceActionDetails =
    List[zio.aws.docdb.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.docdb.model.ResourcePendingMaintenanceActions]
  type ReadReplicaIdentifierList = List[String]
  type ReadersArnList = List[String]
  type SourceIdsList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.docdb.model.Subnet]
  type TagList = List[zio.aws.docdb.model.Tag]
  type ValidUpgradeTargetList = List[zio.aws.docdb.model.UpgradeTarget]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.docdb.model.VpcSecurityGroupMembership]
}
